=============
Code examples
=============

.. toctree::
  :maxdepth: 2


Applications
============

.. fancy_include:: creep_compliance.py


Reproduction tests
==================

.. fancy_include:: stress_reproduced.py

.. fancy_include:: stress_decomposition.py

.. fancy_include:: boundary.py
